==> haskell-extra-1.6.12-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-extra.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: extra
version: 1.6.12
id: extra-1.6.12-DHdLvf94bhcHifO5HapwCI
key: extra-1.6.12-DHdLvf94bhcHifO5HapwCI
license: BSD-3-Clause
copyright: Neil Mitchell 2014-2018
maintainer: Neil Mitchell <ndmitchell@gmail.com>
author: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/extra#readme
synopsis: Extra functions I use.
description:
    A library of extra functions for the standard Haskell libraries. Most functions are simple additions, filling out missing functionality. A few functions are available in later versions of GHC, but this package makes them available back to GHC 7.2.
    .
    The module "Extra" documents all functions provided by this library. Modules such as "Data.List.Extra" provide extra functions over "Data.List" and also reexport "Data.List". Users are recommended to replace "Data.List" imports with "Data.List.Extra" if they need the extra functionality.
category: Development
abi: 36b397877b0e54ac8d0c415a92aec365
exposed: True
exposed-modules:
    Control.Concurrent.Extra Control.Exception.Extra
    Control.Monad.Extra Data.Either.Extra Data.IORef.Extra
    Data.List.Extra Data.Tuple.Extra Data.Typeable.Extra
    Data.Version.Extra Extra Numeric.Extra System.Directory.Extra
    System.Environment.Extra System.IO.Extra System.Info.Extra
    System.Process.Extra System.Time.Extra Text.Read.Extra
hidden-modules: Partial
import-dirs: /usr/lib/ghc-8.4.3/site-local/extra-1.6.12
library-dirs: /usr/lib/ghc-8.4.3/site-local/extra-1.6.12
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/extra-1.6.12
hs-libraries: HSextra-1.6.12-DHdLvf94bhcHifO5HapwCI
depends:
    base-4.11.1.0 directory-1.3.1.5 filepath-1.4.2 process-1.6.3.0
    clock-0.7.2-ErKmPTjVISxJnEb9XKUAOs time-1.8.0.2 unix-2.7.2.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             process-1.6.3.0=b58285e21ceee9f67d7be28ddb8b2627
             clock-0.7.2-ErKmPTjVISxJnEb9XKUAOs=aea2e14c40bb78b61c7d4fb8ecb421a3
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             unix-2.7.2.2=f81aa481840dadf9c364a1cea96978c0
haddock-interfaces: /usr/share/doc/haskell-extra/html/extra.haddock
haddock-html: /usr/share/doc/haskell-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-extra-1.6.13-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-extra.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: extra
version: 1.6.13
id: extra-1.6.13-BctmJ84DfO08xTOI3b2pw9
key: extra-1.6.13-BctmJ84DfO08xTOI3b2pw9
license: BSD-3-Clause
copyright: Neil Mitchell 2014-2018
maintainer: Neil Mitchell <ndmitchell@gmail.com>
author: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/extra#readme
synopsis: Extra functions I use.
description:
    A library of extra functions for the standard Haskell libraries. Most functions are simple additions, filling out missing functionality. A few functions are available in later versions of GHC, but this package makes them available back to GHC 7.2.
    .
    The module "Extra" documents all functions provided by this library. Modules such as "Data.List.Extra" provide extra functions over "Data.List" and also reexport "Data.List". Users are recommended to replace "Data.List" imports with "Data.List.Extra" if they need the extra functionality.
category: Development
abi: 51319e47c98b10c5b4c175a949f6fc33
exposed: True
exposed-modules:
    Control.Concurrent.Extra Control.Exception.Extra
    Control.Monad.Extra Data.Either.Extra Data.IORef.Extra
    Data.List.Extra Data.Tuple.Extra Data.Typeable.Extra
    Data.Version.Extra Extra Numeric.Extra System.Directory.Extra
    System.Environment.Extra System.IO.Extra System.Info.Extra
    System.Process.Extra System.Time.Extra Text.Read.Extra
hidden-modules: Partial
import-dirs: /usr/lib/ghc-8.6.1/site-local/extra-1.6.13
library-dirs: /usr/lib/ghc-8.6.1/site-local/extra-1.6.13
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/extra-1.6.13
hs-libraries: HSextra-1.6.13-BctmJ84DfO08xTOI3b2pw9
depends:
    base-4.12.0.0 clock-0.7.2-DpdvDKMysiO5fhuByT1Vyj directory-1.3.3.0
    filepath-1.4.2.1 process-1.6.3.0 time-1.8.0.2 unix-2.7.2.2
haddock-interfaces: /usr/share/doc/haskell-extra/html/extra.haddock
haddock-html: /usr/share/doc/haskell-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
